PDBCleaner
=================

.. currentmodule:: biskit

.. autoclass:: PDBCleaner
   :members:
   :show-inheritance:
   :special-members: __init__

   

   
   .. rubric:: Methods Overview

   .. autosummary::
      :nosignatures:
   
   
      ~PDBCleaner.__init__
      ~PDBCleaner.capACE
      ~PDBCleaner.capNME
      ~PDBCleaner.capTerminals
      ~PDBCleaner.convertChainIdsCter
      ~PDBCleaner.convertChainIdsNter
      ~PDBCleaner.filterProteinChains
      ~PDBCleaner.logWrite
      ~PDBCleaner.process
      ~PDBCleaner.remove_multi_occupancies
      ~PDBCleaner.remove_non_standard_atoms
      ~PDBCleaner.replace_non_standard_AA
      ~PDBCleaner.unresolvedTerminals
   
   

   
   
   .. rubric:: Attributes Overview

   .. autosummary::
   
      ~PDBCleaner.F_ace_cap
      ~PDBCleaner.F_nme_cap
      ~PDBCleaner.TOLERATE_MISSING
   
   

   
   
   .. raw:: html
      
      <hr>
      <h2>PDBCleaner Method & Attribute Details</h2>

   
   